# Light Labyrinth
Light labyrinth machine learning model.

## How to install?
`pip install light_labyrinth`

## Documentation
Documentation available at <https://lightlabyrinth.org>

## Source code
Source code available at <https://bitbucket.org/Enkar234/lightlabyrinth>